Pyramid
=======

.. currentmodule:: toasty.pyramid

.. autoclass:: Pyramid
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Pyramid.depth

   .. rubric:: Methods Summary

   .. autosummary::

      ~Pyramid.count_leaf_tiles
      ~Pyramid.count_live_tiles
      ~Pyramid.count_operations
      ~Pyramid.new_generic
      ~Pyramid.new_toast
      ~Pyramid.new_toast_filtered
      ~Pyramid.subpyramid
      ~Pyramid.visit_leaves
      ~Pyramid.walk

   .. rubric:: Attributes Documentation

   .. autoattribute:: depth

   .. rubric:: Methods Documentation

   .. automethod:: count_leaf_tiles
   .. automethod:: count_live_tiles
   .. automethod:: count_operations
   .. automethod:: new_generic
   .. automethod:: new_toast
   .. automethod:: new_toast_filtered
   .. automethod:: subpyramid
   .. automethod:: visit_leaves
   .. automethod:: walk
